
### Description

A metaphor is a figure of speech in which one concept (an "image") stands for another (the "topic"), and in which there is at least one point of comparison between the two. In other words, in metaphor, someone speaks of one thing as if it were a different thing because there is an important way that those two things are alike.

#### Kinds of Metaphors

There are two basic kinds of metaphors: "dead" metaphors and "live" metaphors. They each present a different kind of translation problem.

##### Dead Metaphors

A dead metaphor is a metaphor that has been used so much in the language that its speakers no longer regard it as one concept standing for another. Dead metaphors are extremely common. Examples in English are "table leg," "family tree," "leaf" meaning a page in a book, and "crane" meaning a large machine for lifting heavy loads. English speakers simply think of these words as having more than one meaning. Examples in Biblical Hebrew are "hand" to mean "power," "face" to mean "presence," and speaking of emotions or moral qualities as if they were "clothing." 

To learn how to deal with dead metaphors, see [[rc://en/ta/man/jit/figs-metaphordead]].

##### Live Metaphors

These are metaphors that people recognize as one concept standing for another concept, or one thing for another thing. They make people think about how the one thing is like the other thing, because in most ways the two things are very different. People also easily recognize these metaphors as giving strength and unusual qualities to the message. For this reason, people pay attention to these metaphors. 

Live metaphors are the metaphors that need special care to translate correctly. To do so, we need to understand the parts of a metaphor and how they work together to produce meaning. See [[rc://en/ta/man/jit/figs-metaphorparts]].

The rest of this topic deals with live metaphors. 

### Reasons this is a translation issue

* People may not recognize that something is a metaphor. In other words, they may mistake a metaphor for a literal statement, and thus misunderstand it.
* People may not be familiar with the thing that is used as an image, and so not be able to understand the metaphor.
* If the topic is not stated, people may not know what the topic is.
* People may not know the points of comparison that the speaker wants them to understand. If they fail to think of these points of comparison, they will not understand the metaphor.
* People may think that they understand the metaphor, but they do not. This can happen when they apply points of comparison from their own culture, rather than from the biblical culture.

### Translation principles

* Make the meaning of a metaphor as clear to the target audience as it was to the original audience.
* Do not make the meaning of a metaphor more clear to the target audience than you think it was to the original audience.

### Examples from the Bible 

**Sometimes the speaker makes the topic clear by using a sentence with the verb "be."** Isaiah spoke of God's people being clay and God being their potter, someone who makes pots out of clay.

>Yet, Yahweh, you are our father; <u>we are the clay</u>. <u>You are our potter</u>; and we all are the work of your hand. Be not too angry, Yahweh, nor always call to mind against us our sins. Please look at us all, your people. (Isaiah 64:8, 9 ULB)

* The topics are "we" and "you," and the images are "clay" and "potter." The intended point of comparison is that a potter values what he has made out of clay, and God loves the people whom he has made to be his own. Isaiah reminds God of this as a basis for asking God not to be too angry with them.

**Sometimes the speaker does not make the topic clear. The audience has to understand it from other things the speaker says.** When Jesus referred to Saul kicking a goad, he was showing that Saul's persecuting Jesus was a like an animal kicking against a goad.

>Saul, Saul, why do you persecute me? It is hard for you <u>to kick a goad</u>. (Acts 26:14 ULB)

* A goad is a pointed stick that a person pokes his cattle with to make them move in a certain direction. Sometimes cattle resist their master and kick the sharp stick and hurt themselves. Instead of following Jesus, Saul was persecuting people who followed Jesus. He was resisting Jesus.

**Sometimes the original audience did not understand the metaphor.** Jesus used a metaphor with the word "yeast", but his disciples did not realize it. They thought he was talking about bread.

>Jesus said to them, "Take heed and beware of <u>the yeast of the Pharisees and Sadducees</u>." The disciples reasoned among themselves and said, "It is because we took no bread." (Matthew 16:6-7 ULB)

* However, "yeast" was the image in Jesus' metaphor, and the topic was the teaching of the Pharisees and Sadducees. Jesus wanted his disciples to beware of the false teaching of the Pharisees and Sadducees. Since the disciples did not understand what Jesus meant, it would not be good to state clearly here what Jesus meant.

### Translation Strategies

If people would understand the metaphor in the same way that the original readers would have understood it, go ahead and use it. Be sure to test the translation to make sure that people do understand it in the right way.

If people do not or would not understand it, here are some other strategies.

1. If the target audience does not realize that it is a metaphor, then change the metaphor to a simile. Some languages do this by adding "like" or "as." See [Simile](../figs-simile/01.md).
1. If the target audience would not know the **image**, see [Translate Unknowns](../translate-unknown/01.md) for ideas on how to translate that image.
1. If the target audience would not use that **image** for that meaning, use an image from your own culture instead. Be sure that it is an image that could have been possible in Bible times.
1. If the target audience would not know what the **topic** is, then state the topic clearly. (However, do not do this if the original audience did not know what the topic was.)
1. If the target audience would not know the intended **point of comparison** between the topic and the image, then state it clearly.
1. If none of these strategies is satisfactory, then simply state the idea plainly without using a metaphor.

### Examples of Translation Strategies Applied
    
1. If the target audience does not realize that it is a metaphor, then change the metaphor to a simile. Some languages do this by adding "like" or "as."
  * **Yet, Yahweh, you are our father; we are the <u>clay</u>. You are our <u>potter</u>; and we all are the work of your hand.** (Isaiah 64:8 ULB)
      * Yet, Yahweh, you are our father; we are <u>like</u> clay. You are <u>like</u> a potter; and we all are the work of your hand.   
   
1. If the target audience would not know the **image**, see [Translate Unknowns](../translate-unknown/01.md) for ideas on how to translate that image.
  * **... Saul, Saul, why do you persecute me? It is hard for you <u>to kick a goad</u>.** (Acts 26:14 ULB)
      * ... Saul, Saul, why do you persecute me? It is hard for you to <u>kick against a pointed prodding stick</u>.   
   
1. If the target audience would not use that **image** for that meaning, use an image from your own culture instead. Be sure that it is an image that could have been possible in Bible times.
  * **Yet, Yahweh, you are our father; we are the <u>clay</u>. You are our <u>potter</u>; and we all are the work of your hand.** (Isaiah 64:8 ULB)
      * Yet, Yahweh, you are our father; we are the <u>wood</u>. You are our <u>carver</u>; and we all are the work of your hand.
      * Yet, Yahweh, you are our father; we are the <u>string</u>. You are the <u>weaver</u>; and we all are the work of your hand.   
   
1. If the target audience would not know what the **topic** is, then state the topic clearly. (However, do not do this if the original audience did not know what the topic was.)
  * **Yahweh lives; may <u>my rock</u> be praised. May the God of my salvation be exalted.** (Psalm 18:46 ULB)
      * Yahweh lives; <u>He is my rock</u>. May he be praised. May the God of my salvation be exalted.   
   
1. If the target audience would not know the intended **point of comparison** between the topic and the image, then state it clearly.
  * **Yahweh lives; may <u>my rock</u> be praised. May the God of my salvation be exalted.** (Psalm 18:46 ULB)
      * Yahweh lives; may he be praised because he <u>protects me like the rock under which I can hide from my enemies</u>. May the God of my salvation be exalted.
  * **... Saul, Saul, why do you persecute me? It is hard for you <u>to kick a goad</u>.** (Acts 26:14 ULB)
      * ... Saul, Saul, why do you persecute me? You <u>fight against me and hurt yourself like an ox that kicks against its owner's goad</u>.   
   
1. If none of these strategies are satisfactory, then simply state the idea plainly without using a metaphor.
  * **... I will make you <u>fishers of men</u>.** (Mark 1:17 ULB)
      * ... I will make you <u>people who gather men</u>.
      * ... Now you gather fish. I will make you <u>gather people</u>.  
  

To learn more about specific metaphors, see [Biblical Imagery - Common Patterns](../bita-part1/01.md).

